<a id="mypy-boto3-cloudsearch"></a>

# mypy-boto3-cloudsearch

[![PyPI - types-aiobotocore-cloudsearch](https://img.shields.io/pypi/v/types-aiobotocore-cloudsearch.svg?color=blue)](https://pypi.org/project/types-aiobotocore-cloudsearch)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-cloudsearch.svg?color=blue)](https://pypi.org/project/types-aiobotocore-cloudsearch)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-cloudsearch?color=blue)](https://pypistats.org/packages/types-aiobotocore-cloudsearch)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.CloudSearch 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudsearch.html#CloudSearch)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-cloudsearch docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_cloudsearch/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-cloudsearch](#mypy-boto3-cloudsearch)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `CloudSearch`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `CloudSearch` service.

```bash
python -m pip install types-aiobotocore[cloudsearch]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[cloudsearch]` in your environment:
  `python -m pip install 'types-aiobotocore[cloudsearch]'`

Both type checking and auto-complete should work for `CloudSearch` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[cloudsearch]` in your environment:
  `python -m pip install 'types-aiobotocore[cloudsearch]'`

Both type checking and auto-complete should work for `CloudSearch` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[cloudsearch]` in your environment:
  `python -m pip install 'types-aiobotocore[cloudsearch]'`
- Run `mypy` as usual

Type checking should work for `CloudSearch` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[cloudsearch]` in your environment:
  `python -m pip install 'types-aiobotocore[cloudsearch]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CloudSearch` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`CloudSearchClient` provides annotations for
`session.create_client("cloudsearch")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_cloudsearch import CloudSearchClient

session = get_session()
with async session.create_client("cloudsearch") as client:
    client: CloudSearchClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="literals"></a>

### Literals

`types_aiobotocore_cloudsearch.literals` module contains literals extracted
from shapes that can be used in user code for type checking.

```python
from types_aiobotocore_cloudsearch.literals import (
    AlgorithmicStemmingType,
    AnalysisSchemeLanguageType,
    IndexFieldTypeType,
    OptionStateType,
    PartitionInstanceTypeType,
    SuggesterFuzzyMatchingType,
    TLSSecurityPolicyType,
    ServiceName,
)

def check_value(value: AlgorithmicStemmingType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`types_aiobotocore_cloudsearch.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_cloudsearch.type_defs import (
    AccessPoliciesStatusTypeDef,
    AnalysisOptionsTypeDef,
    AnalysisSchemeStatusTypeDef,
    AnalysisSchemeTypeDef,
    AvailabilityOptionsStatusTypeDef,
    BuildSuggestersRequestRequestTypeDef,
    BuildSuggestersResponseTypeDef,
    CreateDomainRequestRequestTypeDef,
    CreateDomainResponseTypeDef,
    DateArrayOptionsTypeDef,
    DateOptionsTypeDef,
    DefineAnalysisSchemeRequestRequestTypeDef,
    DefineAnalysisSchemeResponseTypeDef,
    DefineExpressionRequestRequestTypeDef,
    DefineExpressionResponseTypeDef,
    DefineIndexFieldRequestRequestTypeDef,
    DefineIndexFieldResponseTypeDef,
    DefineSuggesterRequestRequestTypeDef,
    DefineSuggesterResponseTypeDef,
    DeleteAnalysisSchemeRequestRequestTypeDef,
    DeleteAnalysisSchemeResponseTypeDef,
    DeleteDomainRequestRequestTypeDef,
    DeleteDomainResponseTypeDef,
    DeleteExpressionRequestRequestTypeDef,
    DeleteExpressionResponseTypeDef,
    DeleteIndexFieldRequestRequestTypeDef,
    DeleteIndexFieldResponseTypeDef,
    DeleteSuggesterRequestRequestTypeDef,
    DeleteSuggesterResponseTypeDef,
    DescribeAnalysisSchemesRequestRequestTypeDef,
    DescribeAnalysisSchemesResponseTypeDef,
    DescribeAvailabilityOptionsRequestRequestTypeDef,
    DescribeAvailabilityOptionsResponseTypeDef,
    DescribeDomainEndpointOptionsRequestRequestTypeDef,
    DescribeDomainEndpointOptionsResponseTypeDef,
    DescribeDomainsRequestRequestTypeDef,
    DescribeDomainsResponseTypeDef,
    DescribeExpressionsRequestRequestTypeDef,
    DescribeExpressionsResponseTypeDef,
    DescribeIndexFieldsRequestRequestTypeDef,
    DescribeIndexFieldsResponseTypeDef,
    DescribeScalingParametersRequestRequestTypeDef,
    DescribeScalingParametersResponseTypeDef,
    DescribeServiceAccessPoliciesRequestRequestTypeDef,
    DescribeServiceAccessPoliciesResponseTypeDef,
    DescribeSuggestersRequestRequestTypeDef,
    DescribeSuggestersResponseTypeDef,
    DocumentSuggesterOptionsTypeDef,
    DomainEndpointOptionsStatusTypeDef,
    DomainEndpointOptionsTypeDef,
    DomainStatusTypeDef,
    DoubleArrayOptionsTypeDef,
    DoubleOptionsTypeDef,
    ExpressionStatusTypeDef,
    ExpressionTypeDef,
    IndexDocumentsRequestRequestTypeDef,
    IndexDocumentsResponseTypeDef,
    IndexFieldStatusTypeDef,
    IndexFieldTypeDef,
    IntArrayOptionsTypeDef,
    IntOptionsTypeDef,
    LatLonOptionsTypeDef,
    LimitsTypeDef,
    ListDomainNamesResponseTypeDef,
    LiteralArrayOptionsTypeDef,
    LiteralOptionsTypeDef,
    OptionStatusTypeDef,
    ResponseMetadataTypeDef,
    ScalingParametersStatusTypeDef,
    ScalingParametersTypeDef,
    ServiceEndpointTypeDef,
    SuggesterStatusTypeDef,
    SuggesterTypeDef,
    TextArrayOptionsTypeDef,
    TextOptionsTypeDef,
    UpdateAvailabilityOptionsRequestRequestTypeDef,
    UpdateAvailabilityOptionsResponseTypeDef,
    UpdateDomainEndpointOptionsRequestRequestTypeDef,
    UpdateDomainEndpointOptionsResponseTypeDef,
    UpdateScalingParametersRequestRequestTypeDef,
    UpdateScalingParametersResponseTypeDef,
    UpdateServiceAccessPoliciesRequestRequestTypeDef,
    UpdateServiceAccessPoliciesResponseTypeDef,
)

def get_structure() -> AccessPoliciesStatusTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`types-aiobotocore-cloudsearch` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[types-aiobotocore-cloudsearch docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_cloudsearch/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
